Struct WpDrmLeaseDeviceV1
pub struct WpDrmLeaseDeviceV1 { /* private fields */ }wayland and Linux only.Expand description
lease device
This protocol is used by Wayland compositors which act as Direct Rendering Manager (DRM) masters to lease DRM resources to Wayland clients.
The compositor will advertise one wp_drm_lease_device_v1 global for each DRM node. Some time after a client binds to the wp_drm_lease_device_v1 global, the compositor will send a drm_fd event followed by zero, one or more connector events. After all currently available connectors have been sent, the compositor will send a wp_drm_lease_device_v1.done event.
When the list of connectors available for lease changes the compositor will send wp_drm_lease_device_v1.connector events for added connectors and wp_drm_lease_connector_v1.withdrawn events for removed connectors, followed by a wp_drm_lease_device_v1.done event.
The compositor will indicate when a device is gone by removing the global via a wl_registry.global_remove event. Upon receiving this event, the client should destroy any matching wp_drm_lease_device_v1 object.
To destroy a wp_drm_lease_device_v1 object, the client must first issue a release request. Upon receiving this request, the compositor will immediately send a released event and destroy the object. The client must continue to process and discard drm_fd and connector events until it receives the released event. Upon receiving the released event, the client can safely cleanup any client-side resources.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Event enum for this interface.
Implementations
impl WpDrmLeaseDeviceV1
impl WpDrmLeaseDeviceV1
pub fn create_lease_request<U, D>(
&self,
qh: &QueueHandle<D>,
udata: U,
) -> WpDrmLeaseRequestV1
pub fn create_lease_request<U, D>( &self, qh: &QueueHandle<D>, udata: U, ) -> WpDrmLeaseRequestV1
create a lease request object
Creates a lease request object.
See the documentation for wp_drm_lease_request_v1 for details.
pub fn release(&self)
pub fn release(&self)
release this object
Indicates the client no longer wishes to use this object. In response the compositor will immediately send the released event and destroy this object. It can however not guarantee that the client won’t receive connector events before the released event. The client must not send any requests after this one, doing so will raise a wl_display error. Existing connectors, lease request and leases will not be affected.